==> mantra.1.9.5.1.zip: mantra/admin/defaults.php <==
<?php

// DEFAULT OPTIONS ARRAY

$mantra_defaults = array(

"mantra_db" => "1.0",

"mantra_side" => "2cSr",
"mantra_dimselect" => 'Absolute',
"mantra_sidewidth" => 800,
"mantra_sidebar" => 250,
"mantra_sidewidthRel" => 60,
"mantra_sidebarRel" => 20,
"mantra_hheight" => "60",

"mantra_frontpage" => "Disable",
"mantra_fpsliderwidth" => "800",
"mantra_fpsliderheight" => "250",
"mantra_fpslideranim" => "random",
"mantra_fpslidertime" => "750",
"mantra_fpsliderpause" => "5000",
"mantra_fpslidernav" => "Bullets",
"mantra_fpsliderarrows" => "Visible on Hover",

"mantra_slideType" => "Custom Slides",
"mantra_slideCateg" => "",
"mantra_slideNumber" => "5",
"mantra_slideSpecific" => "",

"mantra_sliderimg1" => get_template_directory_uri()."/images/slider/mantra-slide1.jpg",
"mantra_slidertitle1" => "This is your caption's title",
"mantra_slidertext1" => "And this is the text that could accompany it. It is all optional so if you delete it in the Mantra Settings there will be no more caption with the black background.",
"mantra_sliderlink1" => "",
"mantra_sliderimg2" => get_template_directory_uri()."/images/slider/mantra-slide2.jpg",
"mantra_slidertitle2" => "This is yet another title",
"mantra_slidertext2" => "And some more text to give you as an example. You can use <a href='http://www.riotreaction.com' >links</a> and other type of <b>HTML</b> <i>formats</i>.",
"mantra_sliderlink2" => "",
"mantra_sliderimg3" => "",
"mantra_slidertitle3" => "",
"mantra_slidertext3" => "",
"mantra_sliderlink3" => "",
"mantra_sliderimg4" => "",
"mantra_slidertitle4" => "",
"mantra_slidertext4" => "",
"mantra_sliderlink4" => "",
"mantra_sliderimg5" => "",
"mantra_slidertitle5" => "",
"mantra_slidertext5" => "",
"mantra_sliderlink5" => "",

"mantra_nrcolumns" => "4",
"mantra_colimageheight" => "120",
"mantra_columnreadmore" => "Read more",

"mantra_columnimg1" => get_template_directory_uri()."/images/slider/mantra-column.jpg",
"mantra_columntitle1" => "Hi there!",
"mantra_columntext1" => "You can also have some text here. Just like with the slider, it's all optional (including the title and the link inputs). All you need is an image, unless you want the Mantra image above to follow you everywhere.",
"mantra_columnlink1" => "",
"mantra_columnimg2" => get_template_directory_uri()."/images/slider/mantra-column.jpg",
"mantra_columntitle2" => " HTML tags",
"mantra_columntext2" => "You can also have <a href='http://www.riotreactions.com'>links</a> here as well as all other <strong>HTML tags</strong>.",
"mantra_columnlink2" => "",
"mantra_columnimg3" => get_template_directory_uri()."/images/slider/mantra-column.jpg",
"mantra_columntitle3" => "",
"mantra_columntext3" => "",
"mantra_columnlink3" => "",
"mantra_columnimg4" => get_template_directory_uri()."/images/slider/mantra-column.jpg",
"mantra_columntitle4" => "",
"mantra_columntext4" => "",
"mantra_columnlink4" => "",

"mantra_fronttext1" => "This could be a tile",
"mantra_fronttext2" => "And this another one",
"mantra_fronttitlecolor" => "#333333",
"mantra_fronttext3" => "And here you could have a whole lot of text. Or not. It's all up to you. Deleting all text inside the appropriate input in the Mantra Settings will remove this whole text zone. It can also contain all HTML tags.<br /> Just try everything out and see what suits you. Have fun and good luck! ",
"mantra_fronttext4" => "",

"mantra_fronthideheader" => "",
"mantra_fronthidemenu" => "",
"mantra_fronthidewidget" => "",
"mantra_fronthidefooter" => "",
"mantra_fronthideback" => "",

"mantra_fontfamily" => 'Segoe UI, Arial, sans-serif',
"mantra_googlefont" => '',
"mantra_googlefont2" => '',
"mantra_fontsize" => "14px",
"mantra_fonttitle" => 'Default',
"mantra_googlefonttitle" => '',
"mantra_googlefonttitle2" => '',
"mantra_headfontsize" => "Default",
"mantra_fontside" => 'Default',
"mantra_googlefontside" => '',
"mantra_googlefontside2" => '',
"mantra_sidefontsize" => "Default",
"mantra_fontsubheader" => 'Default',
"mantra_googlefontsubheader" => '',
"mantra_googlefontsubheader2" => '',
"mantra_textalign" => "Default",
"mantra_parindent" => "0px",
"mantra_headerindent" => "Enable",
"mantra_lineheight" => "Default",
"mantra_wordspace" => "Default",
"mantra_letterspace" => "Default",
"mantra_textshadow" => "Enable",

"mantra_backcolor" => "#444444",
"mantra_headercolor" => "#333333",
"mantra_prefootercolor" => "#222222",
"mantra_footercolor" => "#171717",
"mantra_titlecolor" => "#0D85CC",
"mantra_descriptioncolor" => "#999999",
"mantra_contentcolor" => "#333333",
"mantra_linkscolor" => "#0D85CC",
"mantra_hovercolor" => "#12a7ff",
"mantra_headtextcolor" => "#333333",
"mantra_headtexthover" => "#000000",
"mantra_sideheadbackcolor" => "#444444",
"mantra_sideheadtextcolor" => "#2EA5FD",

"mantra_footerheader" => "#0C85CD",
"mantra_footertext" => "#666666",
"mantra_footerhover" => "#888888",

"mantra_caption" => "Light",
"mantra_image" => "Seven",
"mantra_pin" => "Pin2",
"mantra_sidebullet" => "arrow_white",
"mantra_metaback" => "Gray",
"mantra_postseparator" => "Hide",
"mantra_contentlist" => "Show",
"mantra_title" => "Show",
"mantra_pagetitle" => "Show",
"mantra_categtitle" => "Show",
"mantra_tables" => "Disable",
"mantra_backtop" => "Enable",
"mantra_comtext" => "Show",
"mantra_comclosed" => "Hide everywhere",
"mantra_comoff" => "Show",
"mantra_copyright" => "",

"mantra_postcomlink" => "Show",
"mantra_postdate" => "Show",
"mantra_posttime" => "Hide",
"mantra_postauthor" => "Show",
"mantra_postcateg" => "Show",
"mantra_posttag" => "Show",
"mantra_postbook" => "Show",
"mantra_postmetas" => "Show",

"mantra_excerpthome" => "Full Post",
"mantra_excerptsticky" => "Full Post",
"mantra_excerptarchive" => "Full Post",
"mantra_excerptwords" => "50",
"mantra_magazinelayout" => "Disable",
"mantra_excerptdots" => " &hellip;",
"mantra_excerptcont" => " Continue reading",
"mantra_excerpttags" => "Disable",

"mantra_fpost" => "Disable",
"mantra_fpostlink" => "1",
"mantra_fauto" => "Disable",
"mantra_falign" => "Left",
"mantra_fwidth" => "250",
"mantra_fheight" => "150",
"mantra_fcrop" => "",
"mantra_fheader" => "Disable",

"mantra_social1" => "",
"mantra_social2" => "",
"mantra_social3" => "",
"mantra_social4" => "",
"mantra_social5" => "",
"mantra_social6" => "",
"mantra_social7" => "",
"mantra_social8" => "",
"mantra_social9" => "",
"mantra_social10" => "",
"mantra_socialsdisplay0" => "",
"mantra_socialsdisplay1" => "",
"mantra_socialsdisplay2" => "",
"mantra_socialsdisplay3" => "",

"mantra_linkheader" => "Disable",
"mantra_breadcrumbs" => "Disable",
"mantra_pagination" => "Enable",
"mantra_mobile" => "Disable",
"mantra_favicon" => "",
"mantra_customcss" => "/* Mantra Custom CSS */  ",
"mantra_customjs" => "",
"mantra_seo" => "Enable",
"mantra_seo_home_desc" => "",
"mantra_seo_gen_desc" => "Auto",
"mantra_seo_author" => "Do not use");

?>

==> mantra.1.9.6.1.zip: mantra/admin/defaults.php <==
<?php

// DEFAULT OPTIONS ARRAY

$mantra_defaults = array(

"mantra_db" => "1.0",

"mantra_side" => "2cSr",
"mantra_dimselect" => 'Absolute',
"mantra_sidewidth" => 800,
"mantra_sidebar" => 250,
"mantra_sidewidthRel" => 60,
"mantra_sidebarRel" => 20,
"mantra_hheight" => "60",
"mantra_hcenter" => "",

"mantra_frontpage" => "Disable",
"mantra_fpsliderwidth" => "800",
"mantra_fpsliderheight" => "250",
"mantra_fpslideranim" => "random",
"mantra_fpsliderborderwidth" => "10",
"mantra_fpsliderbordercolor" => "#EEEEEE",
"mantra_fpslidertime" => "750",
"mantra_fpsliderpause" => "5000",
"mantra_fpslidernav" => "Bullets",
"mantra_fpsliderarrows" => "Visible on Hover",

"mantra_slideType" => "Custom Slides",
"mantra_slideCateg" => "",
"mantra_slideNumber" => "5",
"mantra_slideSpecific" => "",

"mantra_sliderimg1" => get_template_directory_uri()."/images/slider/mantra-slide1.jpg",
"mantra_slidertitle1" => "This is your caption's title",
"mantra_slidertext1" => "And this is the text that could accompany it. It is all optional so if you delete it in the Mantra Settings there will be no more caption with the black background.",
"mantra_sliderlink1" => "",
"mantra_sliderimg2" => get_template_directory_uri()."/images/slider/mantra-slide2.jpg",
"mantra_slidertitle2" => "This is yet another title",
"mantra_slidertext2" => "And some more text to give you as an example. You can use <a href='http://www.riotreaction.com' >links</a> and other type of <b>HTML</b> <i>formats</i>.",
"mantra_sliderlink2" => "",
"mantra_sliderimg3" => "",
"mantra_slidertitle3" => "",
"mantra_slidertext3" => "",
"mantra_sliderlink3" => "",
"mantra_sliderimg4" => "",
"mantra_slidertitle4" => "",
"mantra_slidertext4" => "",
"mantra_sliderlink4" => "",
"mantra_sliderimg5" => "",
"mantra_slidertitle5" => "",
"mantra_slidertext5" => "",
"mantra_sliderlink5" => "",

"mantra_nrcolumns" => "4",
"mantra_colimageheight" => "120",
"mantra_columnreadmore" => "Read more",

"mantra_columnimg1" => get_template_directory_uri()."/images/slider/mantra-column.jpg",
"mantra_columntitle1" => "Hi there!",
"mantra_columntext1" => "You can also have some text here. Just like with the slider, it's all optional (including the title and the link inputs). All you need is an image, unless you want the Mantra image above to follow you everywhere.",
"mantra_columnlink1" => "",
"mantra_columnimg2" => get_template_directory_uri()."/images/slider/mantra-column.jpg",
"mantra_columntitle2" => " HTML tags",
"mantra_columntext2" => "You can also have <a href='http://www.riotreactions.com'>links</a> here as well as all other <strong>HTML tags</strong>.",
"mantra_columnlink2" => "",
"mantra_columnimg3" => get_template_directory_uri()."/images/slider/mantra-column.jpg",
"mantra_columntitle3" => "",
"mantra_columntext3" => "",
"mantra_columnlink3" => "",
"mantra_columnimg4" => get_template_directory_uri()."/images/slider/mantra-column.jpg",
"mantra_columntitle4" => "",
"mantra_columntext4" => "",
"mantra_columnlink4" => "",

"mantra_fronttext1" => "This could be a tile",
"mantra_fronttext2" => "And this another one",
"mantra_fronttitlecolor" => "#333333",
"mantra_fronttext3" => "And here you could have a whole lot of text. Or not. It's all up to you. Deleting all text inside the appropriate input in the Mantra Settings will remove this whole text zone. It can also contain all HTML tags.<br /> Just try everything out and see what suits you. Have fun and good luck! ",
"mantra_fronttext4" => "",

"mantra_fronthideheader" => "",
"mantra_fronthidemenu" => "",
"mantra_fronthidewidget" => "",
"mantra_fronthidefooter" => "",
"mantra_fronthideback" => "",

"mantra_fontfamily" => 'Segoe UI, Arial, sans-serif',
"mantra_googlefont" => '',
"mantra_googlefont2" => '',
"mantra_fontsize" => "14px",
"mantra_fonttitle" => 'Default',
"mantra_googlefonttitle" => '',
"mantra_googlefonttitle2" => '',
"mantra_headfontsize" => "Default",
"mantra_fontside" => 'Default',
"mantra_googlefontside" => '',
"mantra_googlefontside2" => '',
"mantra_sidefontsize" => "Default",
"mantra_fontsubheader" => 'Default',
"mantra_googlefontsubheader" => '',
"mantra_googlefontsubheader2" => '',
"mantra_textalign" => "Default",
"mantra_parindent" => "0px",
"mantra_headerindent" => "Disable",
"mantra_lineheight" => "Default",
"mantra_wordspace" => "Default",
"mantra_letterspace" => "Default",
"mantra_textshadow" => "Enable",

"mantra_contentbg" => "#FFFFFF",
"mantra_menubg" => "#FAFAFA",
"mantra_backcolor" => "#444444",
"mantra_headercolor" => "#333333",
"mantra_prefootercolor" => "#222222",
"mantra_footercolor" => "#171717",
"mantra_titlecolor" => "#0D85CC",
"mantra_descriptioncolor" => "#999999",
"mantra_contentcolor" => "#333333",
"mantra_linkscolor" => "#0D85CC",
"mantra_hovercolor" => "#12a7ff",
"mantra_headtextcolor" => "#333333",
"mantra_headtexthover" => "#000000",
"mantra_sideheadbackcolor" => "#444444",
"mantra_sideheadtextcolor" => "#2EA5FD",

"mantra_footerheader" => "#0C85CD",
"mantra_footertext" => "#666666",
"mantra_footerhover" => "#888888",

"mantra_caption" => "Light",
"mantra_image" => "Seven",
"mantra_pin" => "Pin2",
"mantra_sidebullet" => "arrow_white",
"mantra_metaback" => "Gray",
"mantra_postseparator" => "Hide",
"mantra_contentlist" => "Show",
"mantra_title" => "Show",
"mantra_pagetitle" => "Show",
"mantra_categtitle" => "Show",
"mantra_tables" => "Disable",
"mantra_backtop" => "Enable",
"mantra_comtext" => "Show",
"mantra_comclosed" => "Hide everywhere",
"mantra_comoff" => "Show",
"mantra_copyright" => "",

"mantra_postcomlink" => "Show",
"mantra_postdate" => "Show",
"mantra_posttime" => "Hide",
"mantra_postauthor" => "Show",
"mantra_postcateg" => "Show",
"mantra_posttag" => "Show",
"mantra_postbook" => "Show",
"mantra_postmetas" => "Show",

"mantra_excerpthome" => "Full Post",
"mantra_excerptsticky" => "Full Post",
"mantra_excerptarchive" => "Full Post",
"mantra_excerptwords" => "50",
"mantra_magazinelayout" => "Disable",
"mantra_excerptdots" => " &hellip;",
"mantra_excerptcont" => " Continue reading",
"mantra_excerpttags" => "Disable",

"mantra_fpost" => "Disable",
"mantra_fpostlink" => "1",
"mantra_fauto" => "Disable",
"mantra_falign" => "Left",
"mantra_fwidth" => "250",
"mantra_fheight" => "150",
"mantra_fcrop" => "",
"mantra_fheader" => "Disable",

"mantra_social1" => "",
"mantra_social2" => "",
"mantra_social3" => "",
"mantra_social4" => "",
"mantra_social5" => "",
"mantra_social6" => "",
"mantra_social7" => "",
"mantra_social8" => "",
"mantra_social9" => "",
"mantra_social10" => "",
"mantra_socialsdisplay0" => "",
"mantra_socialsdisplay1" => "",
"mantra_socialsdisplay2" => "",
"mantra_socialsdisplay3" => "",

"mantra_linkheader" => "Disable",
"mantra_breadcrumbs" => "Disable",
"mantra_pagination" => "Enable",
"mantra_mobile" => "Disable",
"mantra_favicon" => "",
"mantra_customcss" => "/* Mantra Custom CSS */  ",
"mantra_customjs" => "",
"mantra_seo" => "Enable",
"mantra_seo_home_desc" => "",
"mantra_seo_gen_desc" => "Auto",
"mantra_seo_author" => "Do not use");

?>
